@@ -1,27 +1,28 @@
 package WWW::Finger::Fingerpoint;
 
-use 5.008;
-use base qw(WWW::Finger);
+use 5.010;
 use common::sense;
+use utf8;
 
-use Carp;
-use Digest::SHA1 qw(sha1_hex);
-use HTTP::Link::Parser qw(:standard);
-use LWP::UserAgent;
-use RDF::Query::Client;
-use RDF::Trine;
-use URI;
-use WWW::Finger;
+use Carp 0;
+use Digest::SHA1 0 qw[sha1_hex];
+use HTTP::Link::Parser 0.102 qw[:standard];
+use LWP::UserAgent 0;
+use RDF::Query::Client 0.106;
+use RDF::Trine 0.135;
+use URI 0;
 
-our $VERSION = '0.100';
+use parent qw[WWW::Finger];
 
-my $rel_fingerpoint = 'http://ontologi.es/sparql#fingerpoint';
-
-BEGIN
-{
-	push @WWW::Finger::Modules, __PACKAGE__;
+BEGIN {
+	$WWW::Finger::Fingerpoint::AUTHORITY = 'cpan:TOBYINK';
+	$WWW::Finger::Fingerpoint::VERSION   = '0.102';
 }
 
+use constant rel_fingerpoint => 'http://ontologi.es/sparql#fingerpoint';
+
+sub speed { 90 }
+
 sub new
 {
 	my $class = shift;
@@ -47,7 +48,7 @@ sub new
 		unless $response->is_success;
 	
 	my $linkdata = HTTP::Link::Parser::parse_links_to_rdfjson($response);
-	my $sparql   = $linkdata->{ $httphost }->{ $rel_fingerpoint }->[0]->{'value'};
+	my $sparql   = $linkdata->{ $httphost }->{ (rel_fingerpoint) }->[0]->{'value'};
 
 	unless (defined $sparql)
 	{
@@ -159,6 +160,15 @@ sub graph
 	return $self->{'graph'};
 }
 
+sub get
+{
+	my ($self, @params) = @_;
+	return WWW::Finger::_GenericRDF::_simple_sparql(
+		$self,
+		{use_endpoint=>1},
+		map { HTTP::Link::Parser::relationship_uri($_) } @params );
+}
+
 sub endpoint
 {
 	my $self = shift;
@@ -231,6 +241,7 @@ sub key
 }
 
 1;
+
 __END__
 
 =head1 NAME
@@ -273,6 +284,25 @@ WWW::Finger::Fingerpoint - Investigate E-mail Addresses using Fingerpoint
       print "Found page: " . $row->{'page'}->uri . "\n";
     }
   }
+  
+=head1 DESCRIPTION
+
+As well as the standard WWW::Finger methods, WWW::Finger::Fingerpoint provides this
+additional method:
+
+=over
+
+=item C<< get($p1, $p2, ...) >>
+
+$p1, $p2 and are RDF predicate URIs. Returns a list of values which are non-bnode
+objects of triples where the predicate URI is one of the parameters and the 
+subject URI is the person/agent fingered.
+
+  # Returns phone numbers...
+  $finger->get('http://xmlns.com/foaf/0.1/phone',
+               'http://rdf.data-vocabulary.org/#tel');
+
+=back
 
 =head1 SEE ALSO
 
@@ -288,13 +318,17 @@ L<http://www.perlrdf.org/>.
 
 Toby Inkster, E<lt>tobyink@cpan.orgE<gt>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-Copyright (C) 2009-2010 by Toby Inkster
+Copyright (C) 2009-2011 by Toby Inkster
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8 or,
-at your option, any later version of Perl 5 you may have available.
+it under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 =cut
